@@ -1483,17 +1483,20 @@ void UDrawXDown(labelptr curlabel)
 }
 
 /*----------------------------------------------------------------------*/
-/* Find the "real" width and height of an object including pin labels	*/
-/* and so forth that only show up on a schematic when it is the top-	*/
-/* level object.							*/
+/* Find the "real" width, height, and origin of an object including pin	*/
+/* labels and so forth that only show up on a schematic when it is the	*/
+/* top-level object.							*/
 /*----------------------------------------------------------------------*/
 
-int toplevelwidth(objinstptr bbinst)
+int toplevelwidth(objinstptr bbinst, short *rllx)
 {
    short llx, urx;
    short origin, corner;
 
-   if (bbinst->schembbox == NULL) return bbinst->bbox.width;
+   if (bbinst->schembbox == NULL) {
+      if (rllx) *rllx = bbinst->bbox.lowerleft.x;
+      return bbinst->bbox.width;
+   }
 
    origin = bbinst->bbox.lowerleft.x;
    corner = origin + bbinst->bbox.width;
@@ -1504,17 +1507,21 @@ int toplevelwidth(objinstptr bbinst)
    bboxcalc(llx, &origin, &corner);
    bboxcalc(urx, &origin, &corner);
 
+   if (rllx) *rllx = origin;
    return(corner - origin);
 }
 
 /*----------------------------------------------------------------------*/
 
-int toplevelheight(objinstptr bbinst)
+int toplevelheight(objinstptr bbinst, short *rlly)
 {
    short lly, ury;
    short origin, corner;
 
-   if (bbinst->schembbox == NULL) return bbinst->bbox.height;
+   if (bbinst->schembbox == NULL) {
+      if (rlly) *rlly = bbinst->bbox.lowerleft.y;
+      return bbinst->bbox.height;
+   }
 
    origin = bbinst->bbox.lowerleft.y;
    corner = origin + bbinst->bbox.height;
@@ -1525,6 +1532,7 @@ int toplevelheight(objinstptr bbinst)
    bboxcalc(lly, &origin, &corner);
    bboxcalc(ury, &origin, &corner);
 
+   if (rlly) *rlly = origin;
    return(corner - origin);
 }
 
