@@ -181,7 +181,7 @@ extern void dostcount(FILE *, short *, short);
 extern short printparams(FILE *, objinstptr, short);
 extern void varcheck(FILE *, short, objectptr, short *, genericptr, u_char);
 extern void varfcheck(FILE *, float, objectptr, short *, genericptr, u_char);
-extern void varpcheck(FILE *, short, objectptr, int, int, short *, genericptr, u_char);
+extern void varpcheck(FILE *, short, objectptr, int, short *, genericptr, u_char);
 extern void getfile(xcWidget, pointertype, caddr_t);
 extern Boolean nextfilename();
 extern void loadfontlib();
@@ -219,8 +219,7 @@ extern Boolean xc_tilde_expand(char *);
 extern short writelabel(FILE *, stringpart *, short *);
 extern char *writesegment(stringpart *, float *, int *);
 extern void writelabelsegs(FILE *, short *, stringpart *);
-extern void printobjects(FILE *, objectptr, float, float, float, short, short,
-                         objectptr **, short *, int);
+extern void printobjects(FILE *, objectptr, short, short, objectptr **, short *, int);
 
 /* from fontfile.c: */
 
@@ -296,8 +295,8 @@ extern void UDrawCircle(XPoint *, u_char);
 extern void UDrawX(labelptr);
 #ifdef SCHEMA
 extern void UDrawXDown(labelptr);
-extern int  toplevelwidth(objinstptr);
-extern int  toplevelheight(objinstptr);
+extern int  toplevelwidth(objinstptr, short *);
+extern int  toplevelheight(objinstptr, short *);
 extern void extendschembbox(objinstptr, XPoint *, XPoint *);
 #endif
 extern void pinadjust(short, short *, short *, short);
